@@ -413,6 +413,10 @@ script_websocket.onmessage = (e)=> {
         if(document.getElementById('system_user_einleitung'))
         document.getElementById('system_user_einleitung').value = script_setting.UserEinleitung
       }
+      if(script_setting.ProtokolHead){
+        if(document.getElementById('system_user_ProtokolHead'))
+        document.getElementById('system_user_ProtokolHead').value = script_setting.ProtokolHead
+      }
     } catch (error) {
       getError(error)
     }
@@ -761,7 +765,7 @@ function reboot() {
  */
 function biosAnimation() {
   const url = location.origin;
-  const match = url.match(/\d+/); // \d+ sucht nach einer oder mehreren Ziffern
+  const match = url.match(/\d+/)||[0]; // \d+ sucht nach einer oder mehreren Ziffern
 
   const canvas = document.getElementById('biosCanvas');
   const ctx = canvas.getContext('2d');
@@ -1672,6 +1676,10 @@ function setUserWeb(params){
   script_setting.UserWeb = params
 }
 
+function setProtokolHead(params){
+  script_setting.ProtokolHead = params
+}
+
 /**
  * The function `setUserPhone` sets the value of `script_setting.UserPhone` to the provided parameter.
  * @param params - The `params` parameter is the value that will be assigned to the `UserPhone`
@@ -2245,3 +2253,18 @@ function resizeImage(file, callback) {
       };
   };
 }
+
+function updateVisibilityByHeight() {
+  const elements = document.querySelectorAll('.visible-hight');
+  const isVisible = window.innerHeight > 800;
+
+  elements.forEach(el => {
+    el.style.display = isVisible ? '' : 'none';
+  });
+}
+
+// Initial prüfen
+updateVisibilityByHeight();
+
+// Reagiert auf Fensteränderung
+window.addEventListener('resize', updateVisibilityByHeight);
\ No newline at end of file
