@@ -9,6 +9,7 @@ const httpsend = new XMLHttpRequest();
 const setting = new Object();
 setting.text_color = '#ffffff';
 const cw = document.getElementsByClassName("ska")[0].offsetWidth;
+//const cw = 600
 var url_smartcube = getFromLocalStorage('smartcube') || location.host;
 
 const script_host = location.origin;
@@ -137,6 +138,7 @@ ws_ska.onopen = (e)=>{
   //  sitzknochen.send(`session restart ${sessionID}`)
   //  sitzknochen.send(`analysis ["sitbones","anamnesis","x1"]`)
   ws_ska.send('switch create_norm on')
+  ws_ska.send('switch create_jpeg on')
 }
 
 ws_ska.onmessage = (e) =>{
@@ -177,7 +179,7 @@ ws_ska.onmessage = (e) =>{
 
     if(data.wsevent === "hockernorm"){
       console.log('hockernorm data: ',data);
-      
+      hockerNormData = data
       if (data.imagetype === 'ska_live') {
         const gradient = getReducedGradient(contrastLevel);
 
@@ -369,6 +371,7 @@ sitzknochen.onopen = (e)=>{
   //  sitzknochen.send(`session restart ${sessionID}`)
   //  sitzknochen.send(`analysis ["sitbones","anamnesis","x1"]`)
   sendMatte('switch create_norm on')
+  sendMatte('switch create_jpeg on')
 }
 var active = false
 //sitzknochen.onmessage = (e) =>{
@@ -582,7 +585,7 @@ var active = false
 //}
 
 //}
-
+var hockerNormData;
 // Funktion zum Verarbeiten eingehender Nachrichten
 function handleMessage(e) {
   translatejs();
@@ -608,6 +611,7 @@ function handleMessage(e) {
   }
 
   if (data.wsevent === "hockernorm") {
+    hockerNormData = data
     handleHockernorm(data);
   }
 }
@@ -1456,6 +1460,59 @@ function drawHeatmap(matrix, rows, cols, canvas, parentDiv, gradient) {
   }
 }
 
+
+
+function generateCanvasImage(data) {
+  const { n_rows, n_cols, values } = data;
+
+  const cellSize = 20; // Größe der einzelnen "Pixel" im Canvas
+  const canvas = document.createElement("canvas");
+  canvas.width = n_cols * cellSize;
+  canvas.height = n_rows * cellSize;
+  const ctx = canvas.getContext("2d");
+
+  // Skala für Farben (von Schwarz bis Rot)
+  function getColor(value) {
+      const colorMap = [
+          "#000000", "#000030", "#000060", "#000090", "#0000C0", "#0000FF", // Dunkelblau → Hellblau
+          "#0030FF", "#0060FF", "#0090FF", "#00C0FF", "#00FFFF", // Blau → Cyan
+          "#30FFC0", "#60FF90", "#90FF60", "#C0FF30", "#FFFF00", // Cyan → Gelb
+          "#FFC030", "#FF9030", "#FF6020", "#FF3000", "#FF0000"  // Gelb → Rot
+      ];
+
+      // Wertbereich 0–255 in die Farbpalette umwandeln
+      let index = Math.floor((value / 255) * (colorMap.length - 1));
+      return colorMap[index];
+  }
+
+  // Werte durchlaufen (Reihen von **unten nach oben** zeichnen)
+  for (let row = 0; row < n_rows; row++) {
+      for (let col = 0; col < n_cols; col++) {
+          const value = values[(n_rows - 1 - row) * n_cols + col]; // **Zeilen spiegeln**
+          ctx.fillStyle = getColor(value);
+          ctx.fillRect(col * cellSize, row * cellSize, cellSize, cellSize);
+      }
+  }
+
+  // Base64-Bild generieren
+  const base64Image = canvas.toDataURL("image/png");
+
+  // Optional: Herunterladen
+  const a = document.createElement("a");
+  a.href = base64Image;
+  a.download = "generated_image.png";
+  a.click();
+
+  console.log("Base64:", base64Image); // Kann an Node.js geschickt werden
+  return base64Image;
+}
+
+
+
+// Bild generieren
+//const base64 = generateCanvasImage(hockerNormData);
+
+
 $(() => {
     translatejs();
 });
\ No newline at end of file
