@@ -12,6 +12,12 @@ var aLangKeys = new Object();
 var lang = "de";
 let reloadTimer = null;
 
+// aus dem localStorage lesen (oder 0 wenn nichts drin steht)
+const MAX_RELOAD_ATTEMPTS = 5;
+let reloadAttempts = Number(localStorage.getItem('ttystateReloadAttempts') || '0');
+
+
+
 
 const canvas = document.getElementById("heatmapCanvas");
 const container = document.getElementById("container");
@@ -516,7 +522,7 @@ try {
 } catch (error) {
 }
 
-scheduleReloadIfNoState();
+//scheduleReloadIfNoState();
 
 sitzknochen.onopen = (e)=>{
   sendMatte('switch create_norm on')
@@ -1869,25 +1875,54 @@ function newElement(jsn, DOM_Element) {
 // --- Watchdog für Reload, wenn keine Matte aktiv ist ---
 
 function scheduleReloadIfNoState() {
-  // Schon geplant? Dann nichts tun.
+  // Schon ein Timer aktiv? Dann nichts tun.
   if (reloadTimer) return;
 
-  reloadTimer = setTimeout(() => {
-    // Nur wirklich reloaden, wenn beide weiterhin false sind
-    if (!state1 && !state2) {
-      location.reload();
-    } else {
-      // sonst freigeben für zukünftige Checks
-      reloadTimer = null;
+  // Maximale Anzahl Reloads erreicht -> nichts mehr machen
+  if (reloadAttempts >= MAX_RELOAD_ATTEMPTS) {
+    console.warn('Maximale ttystate-Reload-Versuche erreicht, kein weiterer Reload.');
+
+    // Optional etwas im UI anzeigen
+    try {
+      cloud.style.backgroundColor = 'var(--error)';
+      cloud_icon.classList.add('mdi', 'font_xl', 'mdi-cloud-off-outline');
+      cloud_con.innerHTML = 'Keine aktive Matte';
+      cloud_con.setAttribute('key','sitbone_cloud_no_con');
+    } catch (e) {
+      // falls Elemente nicht existieren, ignorieren
     }
-  }, 1000); // 1 Sekunde
+
+    return;
+  }
+
+  reloadTimer = setTimeout(() => {
+    // Nur reloaden, wenn immer noch keine Matte aktiv
+    if (!state1 && !state2) {
+      reloadAttempts++;
+      localStorage.setItem('ttystateReloadAttempts', String(reloadAttempts));
+      console.warn(
+        `Reload wegen ttystate=inactive (Versuch ${reloadAttempts}/${MAX_RELOAD_ATTEMPTS})`
+      );
+      location.reload();
+    }
+    // Timer freigeben
+    reloadTimer = null;
+  }, 1000); // 1 Sekunde nach "inactive"
 }
 
+
+
+
 function cancelReloadTimer() {
   if (reloadTimer) {
     clearTimeout(reloadTimer);
     reloadTimer = null;
   }
+  // Erfolgreiche Verbindung: Versuchs-Zähler zurücksetzen
+  reloadAttempts = 0;
+  localStorage.setItem('ttystateReloadAttempts', '0');
 }
 
+
+
 translatejs()
\ No newline at end of file
